@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/src/tools/qstring.h   2.2.3   edited 2000-09-20 $
+** 
 **
 ** Definition of the QString class, and related Unicode
 ** functions.
@@ -353,6 +353,7 @@ public:
     QString( QChar );				// one-char string
     QString( const QString & );			// impl-shared copy
     QString( const QByteArray& );		// deep copy
+    QString( const QCString& );		        // deep copy
     QString( const QChar* unicode, uint length ); // deep copy
 #ifndef QT_NO_CAST_ASCII
     QString( const char *str );			// deep copy
