@@ -2,7 +2,7 @@
  *
  * $Id: classdef.h,v 1.39 2001/03/19 19:27:39 root Exp $
  *
- * Copyright (C) 1997-2006 by Dimitri van Heesch.
+ * Copyright (C) 1997-2007 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -23,7 +23,7 @@
 #include <qdict.h>
 #include <qstrlist.h>
 
-#include "entry.h"
+//#include "entry.h"
 #include "memberlist.h"
 #include "definition.h"
 #include "sortdict.h"
@@ -56,13 +56,13 @@ class ClassDef : public Definition
 {
   public:
     /*! The various compound types */
-    enum CompoundType { Class=Entry::CLASS_SEC, 
-                        Struct=Entry::STRUCT_SEC, 
-                        Union=Entry::UNION_SEC,
-                        Interface=Entry::INTERFACE_SEC,
-                        Protocol=Entry::PROTOCOL_SEC,
-                        Category=Entry::CATEGORY_SEC,
-                        Exception=Entry::EXCEPTION_SEC
+    enum CompoundType { Class, //=Entry::CLASS_SEC, 
+                        Struct, //=Entry::STRUCT_SEC, 
+                        Union, //=Entry::UNION_SEC,
+                        Interface, //=Entry::INTERFACE_SEC,
+                        Protocol, //=Entry::PROTOCOL_SEC,
+                        Category, //=Entry::CATEGORY_SEC,
+                        Exception //=Entry::EXCEPTION_SEC
                       };
 
     /*! Creates a new compound definition.
@@ -294,6 +294,7 @@ class ClassDef : public Definition
     void setTemplateArguments(ArgumentList *al);
     void setTemplateBaseClassNames(QDict<int> *templateNames);
     void setTemplateMaster(ClassDef *tm);
+    void setTypeConstraints(ArgumentList *al);
     void addMembersToTemplateInstance(ClassDef *cd,const char *templSpec);
     void makeTemplateArgument(bool b=TRUE);
     void setCategoryOf(ClassDef *cd);
@@ -310,6 +311,7 @@ class ClassDef : public Definition
     void mergeMembers();
     void distributeMemberGroupDocumentation();
     void writeDocumentation(OutputList &ol);
+    void writeClassDiagrams(OutputList &ol);
     void writeDocumentationForInnerClasses(OutputList &ol);
     void writeMemberDocumentation(OutputList &ol);
     void writeMemberPages(OutputList &ol);
