@@ -3,7 +3,7 @@
  * 
  *
  *
- * Copyright (C) 1997-2006 by Dimitri van Heesch.
+ * Copyright (C) 1997-2007 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -26,6 +26,7 @@ CommandMap cmdMap[] =
   { "arg",           CMD_LI },
   { "attention",     CMD_ATTENTION },
   { "author",        CMD_AUTHOR },
+  { "authors",       CMD_AUTHORS },
   { "b",             CMD_BOLD },
   { "c",             CMD_CODE },
   { "code",          CMD_STARTCODE },
@@ -89,8 +90,6 @@ CommandMap cmdMap[] =
   { "verbinclude",   CMD_VERBINCLUDE },
   { "version",       CMD_VERSION },
   { "warning",       CMD_WARNING },
-  { "author",        CMD_AUTHOR },
-  { "authors",       CMD_AUTHORS },
   { "throws",        CMD_EXCEPTION },
   { "\\",            CMD_BSLASH },
   { "@",             CMD_AT },
@@ -102,7 +101,9 @@ CommandMap cmdMap[] =
   { "%",             CMD_PERCENT },
   { "_internalref",  CMD_INTERNALREF },
   { "dot",           CMD_DOT },
+  { "msc",           CMD_MSC },
   { "enddot",        CMD_ENDDOT },
+  { "endmsc",        CMD_ENDMSC },
   { "manonly",       CMD_MANONLY },
   { "endmanonly",    CMD_ENDMANONLY },
   { "includelineno", CMD_INCWITHLINES },
@@ -160,7 +161,8 @@ CommandMap htmlTagMap[] =
   { "exception",  XML_EXCEPTION },
   { "include",    XML_INCLUDE },
   { "item",       XML_ITEM },
-  { "list",       XML_LIST },
+  { "list",       XML_LIST }, // type="table|bullet|number"
+  { "listheader", XML_LISTHEADER },
   { "para",       XML_PARA },
   { "param",      XML_PARAM },
   { "paramref",   XML_PARAMREF },
@@ -170,14 +172,15 @@ CommandMap htmlTagMap[] =
   { "see",        XML_SEE },
   { "seealso",    XML_SEEALSO },
   { "summary",    XML_SUMMARY },
+  { "term",       XML_TERM },
   { "value",      XML_VALUE },
   { 0,            0 }
 };
 
 //----------------------------------------------------------------------------
 
-Mapper *Mappers::cmdMapper     = new Mapper(cmdMap);
-Mapper *Mappers::htmlTagMapper = new Mapper(htmlTagMap);
+Mapper *Mappers::cmdMapper     = new Mapper(cmdMap,TRUE);
+Mapper *Mappers::htmlTagMapper = new Mapper(htmlTagMap,FALSE);
 
 void Mappers::freeMappers()
 {
